# -*- coding = UTF-8 -*-
# Author   :buxiubuzhi
# File     : cli.py
# project  : UIAutoProject
# time     : 2020/12/14 16:39
# Describe : 
# ---------------------------------------

import argparse
import os, sys
from lazyTest import __version__, __description__

PY3 = sys.version_info[0] == 3


def main():
    """
    API test: parse command line options and run commands.
    """

    parser = argparse.ArgumentParser(description=__description__)
    parser.add_argument(
        '-v', '--version', dest='version', action='store_true',
        help="show version")

    parser.add_argument(
        '--project',
        help="Create an lazyTest automation test project.")

    parser.add_argument(
        '-r',
        help="run test case")

    args = parser.parse_args()

    # 获取版本
    if args.version:
        print("version {}".format(__version__))
        return 0

    # 创建项目
    project_name = args.project
    if project_name:
        create_scaffold(project_name)
        return 0

    # 运行用例
    run_file = args.r
    if run_file:
        if PY3:
            ret = os.system("python -V")
            if ret != 0:
                os.system("python3 -V")
                command = "python3 " + run_file
            else:
                command = "python " + run_file
        else:
            raise NameError("Does not support python2")
        os.system(command)
        return 0


def create_scaffold(project_name):
    """
    create scaffold with specified project name.
    """
    if os.path.isdir(project_name):
        print("{}:Not a directory".format(project_name))
        return

    def create_folder(path):
        print("create dir:{}".format(path))
        os.makedirs(path)

    def create_file(path, file_content=""):
        print("create file:{}".format(path))
        with open(path, 'w', encoding='utf-8') as f:
            f.write(file_content)

    # ----------------------------------------------
    conftest = """
# -*- coding = UTF-8 -*-
# Author   :buxiubuzhi
# File     : conftest.py
# time     : 
# Describe :
# ---------------------------------------
import os
import sys
import time

import allure
import pytest

sys.path.append(os.path.dirname(os.path.dirname(__file__)))
from lazyTest import *

globals()["driver"] = None


def pytest_addoption(parser):
    # 添加参数到pytest.ini
    parser.addini('Terminal', help='访问浏览器参数')
    parser.addini('URL', help='添加 url 访问地址参数')
    parser.addini('filepath', help='添加 截图路径')
    parser.addini('logpath', help='添加 日志路径')


@pytest.fixture(scope='session')
def getdriver(pytestconfig):
    Terminal = pytestconfig.getini("Terminal")
    URL = pytestconfig.getini("URL")
    driver = browser_Config(Terminal, URL)
    globals()["driver"] = driver.base_driver
    yield driver
    driver.browser_close()


@pytest.fixture(scope="function")
def flush_browser(getdriver):
    yield
    getdriver.flush_browser()
    getdriver.sleep(1)


# 用例出现异常或失败时截图
@pytest.hookimpl(hookwrapper=True)
def pytest_runtest_makereport(item):
    config = item.config
    outcome = yield
    report = outcome.get_result()
    if report.when == 'call':
        xfail = hasattr(report, 'wasxfail')
        if report.failed and not xfail:
            project = str(config.rootpath)
            filepath = config.getini("filepath")
            picture_time = time.strftime("%Y-%m-%d-%H-%M-%S", time.localtime(time.time()))
            filename = project + filepath + picture_time + ".png"
            globals()["driver"].save_screenshot(filename)
            with open(filename, "rb") as f:
                file = f.read()
                allure.attach(file, "失败截图", allure.attachment_type.PNG)


@pytest.hookimpl(hookwrapper=True, tryfirst=True)
def pytest_runtest_setup(item):
    config = item.config
    project = str(config.rootpath)
    logpath = config.getini("logpath")
    logging_plugin = config.pluginmanager.get_plugin("logging-plugin")
    logging_plugin.set_log_path(project + logpath)
    yield

    """

    pytest = """
[pytest]


log_cli = true
log_cli_level = INFO
log_format = %(levelname)s %(asctime)s [%(filename)s:%(lineno)-s] %(message)s
log_date_format = %Y-%M-%D %H:%M:%S



log_file_level = INFO
log_file_format = %(levelname)s %(asctime)s [%(filename)s:%(lineno)-s] %(message)s
log_file_date_format = %Y-%M-%D %H:%M:%S


Terminal = ChromeOptions
URL = 
filepath = /result/screenshot/
logpath = /result/log/log.log
    """

    main = """
import os
import sys
import time

sys.path.append(os.path.dirname(os.path.dirname(__file__)))
from lazyTest import ClearTestResult


def getPorjectPath():
    '''
    获取项目路径
    '''
    return os.path.dirname(os.path.dirname(__file__))


def clearLogAndReport():
    print("----------清空上次测试结果----------")
    path = getPorjectPath() + "/result"
    ClearTestResult(path)
    time.sleep(2)
    print("----------测试结果清空成功----------")


def runlastFailed():
    print("启动失败用例重跑")
    cmd = "pytest -s --lf {}/case --alluredir {}/result/report".format(getPorjectPath(), getPorjectPath())
    print(os.system(cmd))


def startReport():
    print("-------------启动测试报告--------------")
    cmd = "allure serve {}/result/report".format(getPorjectPath())
    print(os.system(cmd))


def startCase(cases):
    print("------------开始执行测试------------")
    cmd = "pytest -s {}/case/{} --alluredir {}/result/report".format(getPorjectPath(), cases, getPorjectPath())
    print(os.system(cmd))


def run(cases=" "):
    clearLogAndReport()
    startCase(cases)
    s = input("请选择要启用的服务:1:启动失败用例重跑;\t2：启动测试报告;")
    if s == "1":
        runlastFailed()
        s = input("是否启动测试报告:y/n")
    if s == "2" or s == "y":
        startReport()


run()
    """
    # ----------------------------------------------
    RegisterCase = """
# -*- coding = UTF-8 -*-
# Author   :buxiubuzhi
# File     :test_RegisterCase.py
# time     :2020/11/28  14:55
# Describe : 注册的测试用例
# ---------------------------------------
import allure
import pytest

import lazyTest
from service.RegisterService import RegisterService


class TestRegister(lazyTest.TestCase):

    @pytest.fixture(scope="function")
    def setUp(self, getdriver, flush_browser):
        self.reg = RegisterService(getdriver)

    @allure.title("用户注册")
    def testRegister(self, setUp):
        account = lazyTest.createData("account{}")
        result = self.reg.userRegister(account, account, "123456", "123456", "问题", "答案")
        assert result == "注册成功,快去登录吧！"
    """

    RegisterService = """
# -*- coding = UTF-8 -*-
# Autohr   :buxiubuzhi
# File     :RegisterService.py
# time     :2020/11/28  14:46
# Describe : 注册流程
# ---------------------------------------
import allure

from pages.RegisterPage import RegisterPage


@allure.feature("注册业务")
class RegisterService:

    def __init__(self, driver):
        self.r = RegisterPage(driver)

    @allure.story("用户注册")
    def userRegister(self, account, username, password, repassword, issue, answer):
        self.r.getRegisterPage()
        self.r.inputAccount(account)
        self.r.inputUsername(username)
        self.r.inputPassword(password)
        self.r.inputRepassword(repassword)
        self.r.inputIssue(issue)
        self.r.inputAnswer(answer)
        self.r.clickSubmit()
        return self.reg.getalertText()
    """

    RegisterPage = """
# -*- coding = UTF-8 -*-
# Autohr   :buxiubuzhi
# File     :RegisterPage.py
# time     :2020/11/28  14:36
# Describe : 注册页面
# ---------------------------------------
import os

import allure
import lazyTest



class RegisterPage(lazyTest.Page):

    def getProjectPath(self) -> str:
        return os.path.dirname(os.path.dirname(__file__))

    @lazyTest.Sleep()
    @allure.step("进入注册页面")
    def getRegisterPage(self):
        self.log.info("进入注册页面")
        self.base_driver.get(self.selector["REGISTER"])

    @lazyTest.Sleep()
    @allure.step("输入账号:{account}")
    def inputAccount(self, account):
        self.log.info("输入账号：%s" % account)
        self.base_driver.element_clear_input(self.selector["ACCOUNT"], account)

    @lazyTest.Sleep()
    @allure.step("输入用户名:{username}")
    def inputUsername(self, username):
        self.log.info("输入用户名：%s" % username)
        self.base_driver.element_clear_input(self.selector["USERNAME"], username)

    @lazyTest.Sleep()
    @allure.step("输入密码:{password}")
    def inputPassword(self, password):
        self.log.info("输入密码：%s" % password)
        self.base_driver.element_clear_input(self.selector["PASSWORD"], password)

    @lazyTest.Sleep()
    @allure.step("在次输入密码:{repassword}")
    def inputRepassword(self, repassword):
        self.log.info("在次输入密码：%s" % repassword)
        self.base_driver.element_clear_input(self.selector["REPASSWORD"], repassword)

    @lazyTest.Sleep()
    @allure.step("输入安全问题:{issue}")
    def inputIssue(self, issue):
        self.log.info("输入安全问题：%s" % issue)
        self.base_driver.element_clear_input(self.selector["ISSUE"], issue)

    @lazyTest.Sleep()
    @allure.step("输入答案:{answer}")
    def inputAnswer(self, answer):
        self.log.info("输入答案：%s" % answer)
        self.base_driver.element_clear_input(self.selector["ANSWER"], answer)

    @lazyTest.Sleep()
    @allure.step("点击提交")
    def clickSubmit(self):
        self.log.info("点击提交")
        self.base_driver.element_click(self.selector["SUBMIT"])

    @lazyTest.Sleep()
    @allure.step("获取注册后的弹窗文本")
    def getalertText(self):
        text = self.base_driver.getAlertText()
        self.log.info("弹窗的文本：%s" % text)
        return text
    """

    RegisterPageyaml = """
REGISTER: /view/register.html
ACCOUNT: x,//*[@id="account"]/input
USERNAME: x,/html/body/div/div/div/form/div[2]/input
PASSWORD: x,/html/body/div/div/div/form/div[3]/input
REPASSWORD: x,/html/body/div/div/div/form/div[4]/input
ISSUE: x,/html/body/div/div/div/form/div[5]/input
ANSWER: x,/html/body/div/div/div/form/div[6]/input
SUBMIT: x,/html/body/div/div/div/form/div[7]/button
    """
    # ----------------------------------------------

    create_folder(project_name)  # 创建项目目录
    # 创建目录结构
    create_folder(os.path.join(project_name, "pages"))
    create_folder(os.path.join(project_name, "service"))
    create_folder(os.path.join(project_name, "case"))
    create_folder(os.path.join(project_name, "main"))
    create_folder(os.path.join(project_name, "result"))
    create_folder(os.path.join(project_name, "result", "log"))
    create_folder(os.path.join(project_name, "result", "report"))
    create_folder(os.path.join(project_name, "result", "screenshot"))
    create_folder(os.path.join(project_name, "resources"))
    create_folder(os.path.join(project_name, "resources", "element"))
    # 创建核心文件
    create_file(os.path.join(project_name, "__init__.py"))
    create_file(os.path.join(project_name, "case", "conftest.py"), conftest)
    create_file(os.path.join(project_name, "pytest.ini"), pytest)
    create_file(os.path.join(project_name, "main", "main.py"), main)
    # 创建demo文件
    create_file(os.path.join(project_name, "case", "test_RegisterCase.py"), RegisterCase)
    create_file(os.path.join(project_name, "service", "RegisterService.py"), RegisterService)
    create_file(os.path.join(project_name, "pages", "RegisterPage.py"), RegisterPage)
    create_file(os.path.join(project_name, "resources","element","RegisterPage.yaml"), RegisterPageyaml)


if __name__ == '__main__':
    main()




from lazyTest.file import IniFileOperation,Csv_File_Operation
from lazyTest.utils import Sleep, readElementSource,writeElementKey, ClearTestResult, createData,cls_Sleep
from lazyTest.case import TestCase
from lazyTest.base import  browser_Config
from lazyTest.page import Page

__version__ = '1.1.6'

__author__ = 'buxiubuzhi'

__description__ = "WebUI自动化测试框架"

__all__ = [
    "Sleep",
    "Page",
    "readElementSource",
    "writeElementKey",
    "ClearTestResult",
    "browser_Config",
    "createData",
    "IniFileOperation",
    "TestCase",
    "cls_Sleep",
    "Csv_File_Operation"
]



# project  :Python_Script
# -*- coding = UTF-8 -*-
# Author   :buxiubuzhi
# File     :base.py
# time     :2020/2/13  14:44
# Describe :
# ---------------------------------------
import time

from selenium import webdriver
from selenium.webdriver.common.by import By
from selenium.webdriver.remote.webelement import WebElement
from selenium.webdriver.support import expected_conditions as EC
from selenium.webdriver.support.select import Select
from selenium.webdriver.support.wait import WebDriverWait
from selenium.webdriver.common.action_chains import ActionChains


class browser_Config:
    __locator = {
        'i': By.ID,
        'id': By.ID,
        'n': By.NAME,
        'name': By.NAME,
        'c': By.CLASS_NAME,
        'class': By.CLASS_NAME,
        'x': By.XPATH,
        'xpath': By.XPATH,
        's': By.CSS_SELECTOR,
        'css': By.CSS_SELECTOR,
        't': By.TAG_NAME,
        'tag_name': By.TAG_NAME,
        'l': By.LINK_TEXT,
        "link_text": By.LINK_TEXT,
        'pl': By.PARTIAL_LINK_TEXT,
        'partial_link_text': By.PARTIAL_LINK_TEXT
    }

    def __init__(self, Browser_type: str, url: str) -> None:
        """
        初始化浏览器，并输入地址
        :param Browser_type: 浏览器类型
        :param url: 需要打开的网址
        """

        def getChromeOptions():
            option = webdriver.ChromeOptions()
            option.add_argument('--no-sandbox')
            option.add_argument('--headless')
            option.add_argument('--window-size=1920,1080')
            base_driver = webdriver.Chrome(options=option)
            return base_driver

        def getH5():
            mobile = {"deviceName": "iPhone X"}
            option = webdriver.ChromeOptions()
            option.add_experimental_option("mobileEmulation", mobile)
            base_driver = webdriver.Chrome(chrome_options=option)
            return base_driver

        driver = {
            'Chrome': webdriver.Chrome(),
            'Firefox': webdriver.Firefox(),
            'Ie': webdriver.Ie(),
            "Edge": webdriver.Edge(executable_path="msedgedriver.exe"),
            "PhantomJs": webdriver.PhantomJS(),
            'ChromeOptions': getChromeOptions(),
            'h5': getH5()
        }
        self.base_driver = driver[Browser_type]
        self.baseurl = url

    def __get(self, url: str) -> None:
        self.base_driver.get(url=url)
        self.implicitlyWait(10)
        self.base_driver.maximize_window()

    def get(self, url: str) -> None:
        urls = self.baseurl + url
        self.__get(urls)

    def implicitlyWait(self, s: int) -> None:
        """
        隐式等待
        :param s: 休眠时间，单位：秒
        :return:
        """
        self.base_driver.implicitly_wait(s)

    def sleep(self, s: float) -> None:
        """
        强制休眠
        :param s: 休眠时间
        :return:
        """
        time.sleep(s)

    def webdriver_wait(self, selector: str) -> None:
        """显示等待元素"""
        locator = self.__locate_Element_selector(selector)
        WebDriverWait(self.base_driver, 10, 0.5).until(
            EC.presence_of_element_located(locator))

    def __locate_Element_selector(self, selector: str) -> tuple:
        """
        八种定位方式选择
        :param selector: 传入的格式必须为：定位方式，定位元素值，顺序不可改变
        :return: 返回定位方式
        """
        selector_by = selector.split(',')[0].strip()
        selector_value = selector.split(',')[1].strip()
        return self.__locator[selector_by], selector_value

    def locate_element(self, selector: str) -> WebElement:
        """
        定位单个元素
        :param selector: 定位元素的方式和定位元素的值
        :return: 返回定位元素对象
        """
        self.webdriver_wait(selector)
        locator = self.__locate_Element_selector(selector)
        element = self.base_driver.find_element(*locator)
        return element

    def locate_elements(self, selector: str) -> list:
        """
        定位一组元素值
        :param selector: 定位元素的方式和定位元素的值
        :return:
        """
        locator = self.__locate_Element_selector(selector)
        elements = self.base_driver.find_elements(*locator)
        return elements

    def element_click(self, selector: str) -> None:
        """元素点击操作"""
        ele = self.locate_element(selector)
        ele.click()

    def right_click(self, selector: str) -> None:
        """鼠标右键"""
        ele = self.locate_element(selector)
        ActionChains(self.base_driver).context_click(selector)

    def double_click(self, selector: str) -> None:
        """元素双击"""
        ele = self.locate_element(selector)
        ActionChains(self.base_driver).double_click(ele).perform()

    def drag_and_drop(self, source, target):
        """从源元素按住左键不放拖动到指定元素"""
        start = self.locate_element(source)
        end = self.locate_element(target)
        ActionChains(self.base_driver).drag_and_drop(start, end)

    def element_input(self, selector: str, value: str) -> None:
        """元素输入操作"""
        ele = self.locate_element(selector)
        ele.send_keys(value)

    def element_clear(self, selector: str) -> None:
        """元素输入框清空输入内容"""
        ele = self.locate_element(selector)
        ele.clear()

    def element_clear_input(self, selector: str, value: str) -> None:
        """清空输入框并输入内容"""
        ele = self.locate_element(selector)
        ele.clear()
        ele.send_keys(value)

    def get_element_text(self, selector: str) -> str:
        """获取元素文本内容"""
        ele = self.locate_element(selector)
        return ele.text

    def get_elements_text(self, selector: str, index: int = None) -> list:
        """获取一组元素的文本内容"""
        ele = self.locate_elements(selector)
        if index is not None:
            return ele[index].text
        else:
            text_list = [i.text for i in ele]
            return text_list

    def get_elements(self, selector: str, index: int = None) -> list:
        """获取一组元素"""
        ele = self.locate_elements(selector)
        if index is not None:
            return ele[index]
        else:
            return ele

    def get_element_attribute(self, selector: str, value: str = 'value') -> str:
        """
        获取元素属性
        textContent: 可用于获取没有在当前窗口显示的文本内容
        value： 用于获取元素的value属性
        """
        ele = self.locate_element(selector)
        return ele.get_attribute(value)

    def addAttribute(self, selector: str, attributeName: str, value: str):
        '''
        封装向页面标签添加新属性的方法
        '''
        ele = self.locate_element(selector)
        self.base_driver.execute_script("arguments[0].%s=arguments[1]" % attributeName, ele, value)

    def setAttribute(self, selector: str, attributeName: str, value: str):
        '''
        封装设置页面对象的属性值的方法
        '''
        ele = self.locate_element(selector)
        self.base_driver.execute_script("arguments[0].setAttribute(arguments[1],arguments[2])", ele, attributeName,
                                        value)

    def switch_frame_1(self, frame_name: str) -> None:
        """根据框架名称切换"""
        self.base_driver.switch_to.frame(frame_name)

    def switch_frame_2(self, selector: str) -> None:
        """根据框架定位元素值切换"""
        ele = self.locate_element(selector)
        self.base_driver.switch_to.frame(ele)

    def switch_parent_frame(self):
        """切换到父框架"""
        self.base_driver.switch_to.parent_frame()

    def switch_default_content(self):
        """切换到默认框架"""
        self.base_driver.switch_to.default_content()

    def switch_window(self, window_Num=-1):
        """切换窗口默认切换到最后一个"""
        handles = self.base_driver.window_handles()
        self.base_driver.switch_to.window(handles[window_Num])

    def operation_alert(self, operation: str = 'accept'):
        """处理弹窗"""
        alert = self.base_driver.switch_to.alert
        if operation == 'accept':
            alert.accept()
        elif operation == 'dismiss':
            alert.dismiss()

    def select_operation(self, selector: str, operation_type: str, value: str) -> None:
        """下拉框处理"""
        if operation_type == 'index':
            Select(self.locate_element(selector)).deselect_by_index(value)
        elif operation_type == 'value':
            Select(self.locate_element(selector)).deselect_by_value(value)
        elif operation_type == 'text':
            Select(self.locate_element(selector)).deselect_by_visible_text(value)

    def browser_close(self):
        """关闭浏览器"""
        self.base_driver.close()

    def browser_quit(self):
        """退出浏览器"""
        self.base_driver.quit()

    def flush_browser(self):
        """刷新浏览器"""
        self.base_driver.refresh()

    def excute_script(self, script: str) -> None:
        """执行js脚本"""
        self.base_driver.execute_script(script)

    def exhibition_element(self, selector: str) -> None:
        """将元素显示到可见窗口中 """
        self.sleep(2)
        ele = self.locate_element(selector)
        js = "arguments[0].scrollIntoView();"
        self.base_driver.execute_script(js, ele)

    def getALlPageText(self, selector: str) -> list:
        """获取整个页面的一组元素文本，包括没有显示在当前窗口的"""
        js = "return arguments[0].textContent"
        ele = self.locate_elements(selector)
        return [self.base_driver.execute_script(js, i) for i in ele]



# -*- coding = UTF-8 -*-
# Author   :buxiubuzhi
# File     : case.py
# project  : UIAutoProject
# time     : 2020/12/4 18:05
# Describe : 
# ---------------------------------------
import pytest


class TestCase:

    @pytest.fixture(scope="function")
    def setUp(self, getdriver, flush_browser): ...



# -*- coding = UTF-8 -*-
# Author   :buxiubuzhi
# File     : utils.py
# project  : Python_project
# time     : 2020/11/16 17:01
# Describe : 工具类
# ---------------------------------------

import datetime
import inspect
import os
import time
import functools

from lazyTest.file import YamlOperation, IniFileOperation, FileOperation, JsonFileOperation


def Sleep(s: float = 1):
    """
    每个用例的强制休眠。
    """

    def Sleep(func):
        nonlocal s

        @functools.wraps(func)
        def inner(*args):
            time.sleep(s)
            result = func(*args)
            time.sleep(s)
            return result

        return inner

    return Sleep


class cls_Sleep:
    """
    脚本运行之前和脚本运行之后执行休眠操作
    可以提高脚本执行的稳定性
    """

    def __init__(self,s: float = 0.5):
        self.s = s

    def __call__(self, func_or_cls=None):
        if inspect.isfunction(func_or_cls):
            @functools.wraps(func_or_cls)
            def wrapper(*args, **kwargs):
                time.sleep(self.s)
                result = func_or_cls(*args, **kwargs)
                time.sleep(self.s)
                return result
            return wrapper
        elif inspect.isclass(func_or_cls):
            for name, func in list(func_or_cls.__dict__.items()):
                if inspect.isfunction(func):
                    setattr(func_or_cls, name, self(func))
            return func_or_cls
        else:
            raise AttributeError


def createData(body: str = "auto{}"):
    """
    返回给定字符串拼接上时间后的字符
    """
    nowTime = datetime.datetime.strftime(datetime.datetime.now(), "%Y%m%d%H%M")[2:]
    return body.format(nowTime)


def getPorjectPath():
    """
    获取项目路径
    """
    return os.path.dirname(os.path.dirname(__file__))


def ClearTestResult(path: str):
    """
    清空目录中的文件
    参数：path：将会清除该目录下的所有文件，包括子目录文件；
    """
    for i in os.listdir(path):
        path_file = os.path.join(path, i)
        if os.path.isfile(path_file):
            os.remove(path_file)
        else:
            ClearTestResult(path_file)


def readElementSource(fileName: str) -> FileOperation:
    """
    根据文件后缀名创建对应的读取对象
    """
    if fileName != "" and fileName is not None:
        if fileName.endswith(".yaml"):
            return YamlOperation(fileName)
        elif fileName.endswith(".json"):
            return JsonFileOperation(fileName)
        elif fileName.endswith(".ini"):
            return IniFileOperation(fileName)
        else:
            raise Exception("文件类型错误")


def writeElementKey(filepath, fileName, fileType, data: dict):
    # 得到完整文件路径
    realFile = filepath + fileName + fileType
    if os.path.exists(realFile):
        print("文件已存在不进行写入")
    else:
        newdata = {}
        file = None
        for i in data:
            newdata[i.upper()] = data[i]
        if fileType == '.yaml':
            file = YamlOperation
        elif fileType == '.json':
            file = JsonFileOperation
        file.writeFileToDict(realFile, newdata)
        print("文件写入成功！！！")



# -*- coding = UTF-8 -*-
# Author   :buxiubuzhi
# File     : file.py
# project  : Python_project
# time     : 2020/11/16 16:55
# Describe : 资源文件的操作
# ---------------------------------------
import configparser
import csv
import json
import sys
from ruamel import yaml


class FileOperation:
    def __init__(self, filePath):
        self.filePath = filePath

    def readFileToDict(self): ...

    def readFileToList(self): ...


class YamlOperation(FileOperation):

    def readFileToDict(self):
        """读取yaml文件"""
        with open(self.filePath, 'r', encoding='UTF-8')as fp:
            yaml_data = yaml.safe_load(fp)
        return yaml_data

    @staticmethod
    def writeFileToDict(realFile, data):
        """写入yaml文件"""
        with open(realFile, "w", encoding="utf-8") as f:
            yaml.round_trip_dump(data, f, Dumper=yaml.RoundTripDumper, default_flow_style=False)


class IniFileOperation(FileOperation):

    def readFileToDict(self):
        """读取ini文件"""
        config = configparser.ConfigParser()
        config.read(self.filePath)
        return config


class JsonFileOperation(FileOperation):

    def readFileToDict(self):
        """读取json文件"""
        with open(self.filePath, 'r', encoding='utf8')as fp:
            json_data = json.load(fp)
        return json_data

    @staticmethod
    def writeFileToDict(realFile, data):
        """将字典格式数据写入到Json文件"""
        with open(realFile, 'w', encoding='utf8')as fp:
            json.dump(data, fp, ensure_ascii=False)


class Csv_File_Operation(FileOperation):

    def readFileToList(self):
        """读取CSV文件,参数化使用"""
        with open(self.filePath, 'r', encoding='utf8')as fp:
            data_list = [i for i in csv.reader(fp)]
        if len(data_list[0]) == 1:
            data_list.pop(0)  # 去首行
            return [i[0] for i in data_list]
        else:
            data_list.pop(0)  # 去首行

        return data_list



# -*- coding = UTF-8 -*-
# Author   :buxiubuzhi
# File     : page.py
# project  : McenterSystem
# time     : 2020/12/3 11:56
# Describe :
# ---------------------------------------

import logging
from lazyTest import *


class Page(object):
    filePath = r"/resources/element/"

    suffix = ".yaml"

    def __init__(self, base_driver: browser_Config) -> None:
        self.base_driver = base_driver
        self.log = logging.getLogger(self.getClassName())
        self.log.info("元素文件: -> %s" % (self.getProjectPath() + self.filePath + self.getClassName() + self.suffix))
        self.selector = readElementSource(
            self.getProjectPath() + self.filePath + self.getClassName() + self.suffix).readFileToDict()

    def getProjectPath(self) -> str: ...

    @classmethod
    def getClassName(cls):
        return cls.__name__

    @classmethod
    def writeKey(cls):
        """
        自动创建yaml资源文件
        :return:
        """
        key = {}
        methods = list(
            filter(lambda m: not m.startswith("__") and not m.endswith("__") and callable(getattr(cls, m)), dir(cls)))
        methods.pop(methods.index("writeKey"))
        methods.pop(methods.index("getPorjectPath"))
        methods.pop(methods.index("getClassName"))
        for i in methods:
            func = getattr(cls, i)
            doc = func.__doc__
            key[i] = doc
        writeElementKey(cls.getProjectPath(cls) + cls.filePath, cls.getClassName(), cls.suffix, key)



# project  :lazyTest
# -*- coding = UTF-8 -*-
# Autohr   :buxiubuzhi
# File     :setup.py
# time     :2020/12/13  19:50
# Describe :
# ---------------------------------------
import ast
import re

from setuptools import setup, find_packages


_version_re = re.compile(r'__version__\s+=\s+(.*)')

with open('lazyTest/__init__.py', 'rb') as f:
    version = str(ast.literal_eval(_version_re.search(
        f.read().decode('utf-8')).group(1)))
setup(
    name="lazyTest",  # 这里是pip项目发布的名称
    version=version,  # 版本号，数值大的会优先被pip
    keywords=("pip", "lazyTest"),
    description="自动化测试框架",
    long_description="一个基于pytest + selenium + allure 的自动化测试框架",
    url="https://github.com/xingheyang/lazyTest.git",  # 项目相关文件地址，一般是github
    author="buxiubuzhi",
    author_email="xingheyang_99@163.com",
    packages=find_packages(),
    include_package_data=True,
    install_requires=["pytest", "selenium", "allure-pytest", "ruamel.yaml"],  # 这个项目需要的第三方库
    entry_points={'console_scripts':['lazy=lazyTest.cli:main']},
)
